pub(crate) struct CustomAutoRooterGuard<'a, T>where
T: 'a + CustomTrace,{
rooter: &'a mut CustomAutoRooter<T>,
}Expand description
An RAII guard used to root underlying data in CustomAutoRooter until the
guard is dropped (falls out of scope).
The underlying data can be accessed through this guard via its Deref and
DerefMut implementations.
This structure is created by root method on CustomAutoRooter or
by the auto_root! macro.
Fields
rooter: &'a mut CustomAutoRooter<T>Implementations
Sourceimpl<'a, T> CustomAutoRooterGuard<'a, T>where
T: 'a + CustomTrace,
impl<'a, T> CustomAutoRooterGuard<'a, T>where
T: 'a + CustomTrace,
pub fn new( cx: *mut JSContext, rooter: &'a mut CustomAutoRooter<T>, ) -> CustomAutoRooterGuard<'a, T>
pub fn handle(&'a self) -> Handle<'a, T>where
T: RootKind,
pub fn handle_mut(&mut self) -> MutableHandle<'_, T>where
T: RootKind,